/*
 * Copyright (C) 2014 Canonical, Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License version 3, as published by
 * the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
 * SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "promptsessionlistener.h"
#include "logging.h"

namespace ms = mir::scene;

Q_DECLARE_METATYPE(std::shared_ptr<ms::PromptSession>)

PromptSessionListener::PromptSessionListener(QObject *parent) :
    QObject(parent)
{
    DLOG("PromptSessionListener::PromptSessionListener (this=%p)", this);
    qRegisterMetaType<std::shared_ptr<ms::PromptSession>>("std::shared_ptr<mir::scene::PromptSession>");
}

PromptSessionListener::~PromptSessionListener()
{
    DLOG("PromptSessionListener::~PromptSessionListener (this=%p)", this);
}

void PromptSessionListener::starting(std::shared_ptr<ms::PromptSession> const& prompt_session)
{
    DLOG("PromptSessionListener::starting (this=%p, prompt_session=%p)", this, (void*)prompt_session.get());
    Q_EMIT promptSessionStarting(prompt_session);
}

void PromptSessionListener::stopping(std::shared_ptr<ms::PromptSession> const& prompt_session)
{
    DLOG("PromptSessionListener::stopping (this=%p, prompt_session=%p)", this, (void*)prompt_session.get());
    Q_EMIT promptSessionStopping(prompt_session);
}

void PromptSessionListener::prompt_provider_added(ms::PromptSession const& prompt_session,
                                                  std::shared_ptr<ms::Session> const& prompt_provider)
{
    DLOG("PromptSessionListener::prompt_provider_added (this=%p, prompt_session=%p, prompt_provider=%p)",
        this, &prompt_session, (void*)prompt_provider.get());
    Q_EMIT promptProviderAdded(&prompt_session, prompt_provider);
}

void PromptSessionListener::prompt_provider_removed(ms::PromptSession const& prompt_session,
                                                    std::shared_ptr<ms::Session> const& prompt_provider)
{
    DLOG("PromptSessionListener::prompt_provider_removed (this=%p, prompt_session=%p, prompt_provider=%p)",
        this, &prompt_session, (void*)prompt_provider.get());
    Q_EMIT promptProviderRemoved(&prompt_session, prompt_provider);
}
